@@ -482,9 +482,7 @@ prints on C<STDOUT> XS text with core flags, for F<Core.xs>.
 
 my %flags = (
     hdrcpy => { set => 1 },
-    set_dataflow_f => { FLAG => "DATAFLOW_F", noret => 1 },
     fflows => { FLAG => "DATAFLOW_F" },
-    bflows => { FLAG => "DATAFLOW_B" },
     is_inplace => { FLAG => "INPLACE", postset => 1 },
     set_inplace => { FLAG => "INPLACE", noret => 1 },
     donttouch => { FLAG => "DONTTOUCHDATA" },
@@ -493,7 +491,6 @@ my %flags = (
     anychgd => { FLAG => "ANYCHANGED" },
     datachgd => { FLAG => "PARENTDATACHANGED" },
     dimschgd => { FLAG => "PARENTDIMSCHANGED" },
-    tracedebug => { set => 1 },
 );
 
 sub generate_core_flags {
